#!/bin/bash
# Script to install a prebuilt package

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

: ${UBOOT_SPLASH_IMAGE:="../splash.bmp"}
: ${UBOOT_EXTLINUX_TIMEOUT:=20}
: ${EXTLINUX_FILE:="extlinux.conf"}

# Install dir
UBOOT_EXTLINUX_INSTALL_DIR="/boot"

# Cleanup previous installation
do_cleanup_install_loc

do_buildstep_prepend

log_exec install -d ${D}/${UBOOT_EXTLINUX_INSTALL_DIR}
# Install boot script
if [ -e ${B}/${UBOOT_EXTLINUX_BOOTSCR_IMG} ]; then
    log_exec install -m 755 ${B}/${UBOOT_EXTLINUX_BOOTSCR_IMG} ${D}/${UBOOT_EXTLINUX_INSTALL_DIR}
fi

# Install extlinux files

log_exec install -d ${D}/${UBOOT_EXTLINUX_INSTALL_DIR}/extlinux
extFile="${D}/${UBOOT_EXTLINUX_INSTALL_DIR}/extlinux/${EXTLINUX_FILE}"

echo -e "# Generic Distro Configuration file generated by System Workbench For Linux" > $extFile
echo -e "menu title Select the boot mode" >> $extFile

if [ -z ${UBOOT_SPLASH_IMAGE+x} ]; then
    warning "UBOOT_SPLASH_IMAGE not defined, no splash on u-boot start time"
else
	echo -e "MENU BACKGROUND ${UBOOT_SPLASH_IMAGE}" >> $extFile
fi

# Check machine variables
if [ -z ${machine} ]; then
	fatal 1 "machine variable not found. Please verify machine definitions"
fi

if [ -z ${devicetree} ]; then
	fatal 1 "devicetree variable not found. Please verify machine definitions"
fi

if [ -z ${serial_consoles} ]; then
	fatal 1 "serial_consoles variable not found. Please verify machine definitions"
fi

# Retrive first tty device and its baudrate from 'serial_consoles'
for serial_console in $serial_consoles; do
	IFS=: read -r BAUDRATE TTY <<< ${serial_console}
	
	echo -e "TIMEOUT ${UBOOT_EXTLINUX_TIMEOUT}" >> $extFile
	echo -e "DEFAULT ${machine,,}-sdcard" >> $extFile
	echo -e "LABEL ${machine,,}-sdcard" >> $extFile
	echo -e "	KERNEL /uImage" >> $extFile
	echo -e "	FDT /${devicetree}.dtb" >> $extFile
	echo -e "	APPEND root=/dev/mmcblk0p7 rootwait rw console=${TTY},${BAUDRATE}" >> $extFile
	break
done

do_buildstep_append