#!/bin/bash
# Script to run populate rootfs step

# Warning: changing the utils.sh script currently do not invalidate the task...

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

search_all_versions() {
	local pkg="$1"
	local pkg_name=${pkg%%_*}
	local pkg_vers pkg_rev pkg_arch
	if [ "$pkg_name" = "$pkg" ]; then
		pkg_vers='*'
		pkg_arch=
	else
		pkg_vers=${pkg#*_}
		pkg_arch=${pkg_vers#*_}
		if [ "$pkg_arch" = "$pkg_vers" ]; then
			pkg_arch=''
		fi
		pkg_vers=${pkg_vers%_$pkg_arch}
		if [ -n "$pkg_vers" ]; then
			pkg_rev=${pkg_vers#*-}
			if [ "$pkg_rev" = "$pkg_vers" ]; then
				pkg_rev='*'
			else
				pkg_rev="-$pkg_rev"
				pkg_vers=${pkg_vers%%-*}
			fi
		else
			pkg_vers='*'
			pkg-rev=''
		fi
	fi
	local pkg_archs
	if [ -z "$pkg_arch" ]; then
		pkg_archs="$package_arch all any"
	else
		pkg_vers=${pkg_vers%%_*}
		pkg_archs="$pkg_arch"
	fi

	local recipe_id recipe_id_file pkg_id version
	for arch in $pkg_archs; do
		pkg_id="${pkg_name}_${pkg_vers}${pkg_rev}_${arch}"
		for recipe_id_file in $basePackagesDir/$arch/${pkg_id}; do
			if [ -s "$recipe_id_file" ]; then
				for tarball in $baseTarballsDir/$arch/*/${pkg_id}.tar*; do
					 if [ -r "$tarball" ]; then
					 	version=${tarball##*/}
					 	echo ${version%.tar*}
					 fi
				done
			fi
		done
	done | sort -rV | uniq
}

do_buildstep_prepend

basedir=$(dirname "$0")
PKG_INSTALL_LOC="$ROOTFS_LOC"
tempDir=/tmp/populate-rootfs-$package_name.$$

require_script "packaging_utils.sh"

IFS=':' read -ra PACKAGE_ID <<< "$list_bsp_packages:$list_packages"
for package_id in ${PACKAGE_ID[@]}; do
	# Construct the list of additional sub-packages to load
	package_name=${package_id%%_*}
	package_vers=${package_id#${package_name}_}
	name=${package_name//-/_}
	subpkg_name=$(shell_variable_name ${name}_subpackages)
	subpackages="${!subpkg_name:-$generic_subpackages} \
	             ${global_additional_subpackages} \
	             ${platform_additional_subpackages} \
	             ${rootfs_additional_subpackages}"
	rootfs_optional_subpackages=$(
		for subpkg in $subpackges; do
			echo $subpkg
		done | sort | uniq | grep -v '^base$'
	)
	# Now require the listed package and its optional subpackages
	
	require_packages ${package_id}
done

# Configure dynamic linker runtime binding
log_exec ldconfig -r $ROOTFS_LOC

do_buildstep_append
